function varargout = DLAT_pro(varargin)
% DLAT_PRO M-file for DLAT_pro.fig
%      DLAT_PRO, by itself, creates a new DLAT_PRO or raises the existing
%      singleton*.
%
%      H = DLAT_PRO returns the handle to a new DLAT_PRO or the handle to
%      the existing singleton*.
%
%      DLAT_PRO('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in DLAT_PRO.M with the given input arguments.
%
%      DLAT_PRO('Property','Value',...) creates a new DLAT_PRO or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before DLAT_pro_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to DLAT_pro_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help DLAT_pro

% Last Modified by GUIDE v2.5 16-Jun-2017 17:28:39

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @DLAT_pro_OpeningFcn, ...
                   'gui_OutputFcn',  @DLAT_pro_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before DLAT_pro is made visible.
function DLAT_pro_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to DLAT_pro (see VARARGIN)

% Choose default command line output for DLAT_pro
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes DLAT_pro wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = DLAT_pro_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --------------------------------------------------------------------
function File_1_Callback(hObject, eventdata, handles)
% hObject    handle to File_1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)


% --------------------------------------------------------------------
function Open_Callback(hObject, eventdata, handles)
% hObject    handle to Open (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% --------------------------------------------------------------------
function Save_Callback(hObject, eventdata, handles)
% hObject    handle to Save (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)


% --------------------------------------------------------------------
function Import_Callback(hObject, eventdata, handles)
% hObject    handle to Import (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
files=uipickfiles;
handles=guidata(hObject);
handles.files=files;
guidata(hObject,handles)

